@@ -10,14 +10,16 @@ from yelp_fetcher.scraper.user_details_reviews_self import (
 
 
 class Review(TypedDict):
+    user_id: str
     biz_id: str
     biz_name: str
     review_id: str
     review_date: str
 
     @staticmethod
-    def from_scraped_review(scraped_review: ScrapedReview):
+    def from_scraped_review(user_id, scraped_review: ScrapedReview):
         return Review(
+            user_id=user_id,
             biz_id=scraped_review.biz_id,
             biz_name=scraped_review.biz_name,
             review_id=scraped_review.review_id,
@@ -36,8 +38,8 @@ def get_urls(user_id) -> List[str]:
     return list(urls)
 
 
-def fetch_reviews(url) -> List[Review]:
+def fetch_reviews(user_id, url) -> List[Review]:
     user_biz_soup = fetch_soup(url)
     scraped_reviews = get_user_biz_reviews(user_biz_soup)
-    reviews = map(lambda x: Review.from_scraped_review(x), scraped_reviews)
+    reviews = map(lambda x: Review.from_scraped_review(user_id, x), scraped_reviews)
     return list(reviews)
