@@ -1,7 +1,8 @@
+import re
 from collections import namedtuple
 from typing import List
 
-import dateparser
+from yelp_fetcher._util import fetch_soup
 from yelp_fetcher.scraper.bs4_util import get_elements_by_classname
 from yelp_fetcher.scraper.common import get_review_ids
 
@@ -15,6 +16,7 @@ class ScrapedReview(
 USER_REVIEW_URL = (
     "https://www.yelp.com/user_details_reviews_self?rec_pagestart={}&userid={}"
 )
+DATE_REGEX = re.compile(r"[0-9]{1,2}/[0-9]{1,2}/[0-9]{4}")
 
 
 def get_user_details_reviews_self_url(user_id, page=0):
@@ -31,9 +33,14 @@ def get_user_biz_reviews(page) -> List[ScrapedReview]:
 
     review_date_elems = get_elements_by_classname(page, "rating-qualifier")
     review_dates = list(
-        map(lambda elem: dateparser.parse(elem.get_text()), review_date_elems)
+        map(lambda e: re.search(DATE_REGEX, e.get_text()).group(), review_date_elems)
     )
 
     tups = zip(biz_ids, biz_names, review_ids, review_dates)
     scraped_reviews = list(map(lambda tup: ScrapedReview(*tup), tups))
     return scraped_reviews
+
+
+get_user_biz_reviews(
+    fetch_soup(get_user_details_reviews_self_url("5prk8CtPPBHNpa6BOja2ug", 0))
+)
